boofun.analysis.gaussian
==========================

.. automodule:: boofun.analysis.gaussian


   .. rubric:: Functions

   .. autosummary::

      berry_esseen_bound
      clt_approximation
      gaussian_inner_product
      gaussian_noise_sensitivity
      gaussian_noise_stability
      hermite_coefficients
      hermite_polynomial
      multilinear_extension
      ornstein_uhlenbeck_operator
      physicists_hermite
      probabilists_hermite

   .. rubric:: Classes

   .. autosummary::

      GaussianAnalyzer
